[PATCH 07/10] ASoC: wm_adsp: Convert '/' to '-' when normalizing firmware filenames
From: Richard Fitzgerald
Date: Tue Mar 10 2026 - 11:20:17 EST
Don't preserve '/' in firmware filename fields - convert it to '-' like
other punctuation characters.
The code originally normalized the entire string, including the
directory prefix. To prevent breaking the directory it had to preserve
'/' characters in the name, but this meant that the system name and ALSA
prefix must not contain those characters.
It's trivial to skip the directory name prefix and start the
normalization after it, and that means the normalization does not need
to make a special case for '/'.
Signed-off-by: Richard Fitzgerald <rf@xxxxxxxxxxxxxxxxxxxxx>
---
sound/soc/codecs/wm_adsp.c | 9 ++++-----
1 file changed, 4 insertions(+), 5 deletions(-)
diff --git a/sound/soc/codecs/wm_adsp.c b/sound/soc/codecs/wm_adsp.c
index 69e573507df3..034766760c86 100644
--- a/sound/soc/codecs/wm_adsp.c
+++ b/sound/soc/codecs/wm_adsp.c
@@ -776,16 +776,15 @@ static int wm_adsp_request_firmware_file(struct wm_adsp *dsp,
return -ENOMEM;
/*
* Make sure that filename is lower-case and any non alpha-numeric
* characters except full stop and forward slash are replaced with
* hyphens.
*/
- s = *filename;
+ s = *filename + strlen(dir);
while (*s) {
c = *s;
if (isalnum(c))
*s = tolower(c);
- else if ((c != '.') && (c != '/'))
+ else if (c != '.')
*s = '-';
s++;
}
@@ -776,16 +776,15 @@ static int wm_adsp_request_firmware_file(struct wm_adsp *dsp,
return -ENOMEM;
/*
- * Make sure that filename is lower-case and any non alpha-numeric
- * characters except full stop and forward slash are replaced with
- * hyphens.
+ * Make sure that filename after dir is lower-case and any non-alpha-numeric
+ * characters except full-stop are replaced with hyphens.
*/
--
2.47.3